# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	A tiny replacement for Module::Build
Name:		perl-Module-Build-Tiny
Version:	0.048
Release:	1.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://github.com/Perl-Toolchain-Gang/module-build-tiny
Source0:	https://cpan.metacpan.org/modules/by-module/Module/Module-Build-Tiny-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
# Module
BuildRequires:	perl(CPAN::Meta)
BuildRequires:	perl(CPAN::Requirements::Dynamic)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter) >= 5.57
BuildRequires:	perl(ExtUtils::CBuilder)
BuildRequires:	perl(ExtUtils::Config) >= 0.003
BuildRequires:	perl(ExtUtils::Helpers) >= 0.020
BuildRequires:	perl(ExtUtils::Install)
BuildRequires:	perl(ExtUtils::InstallPaths) >= 0.002
BuildRequires:	perl(ExtUtils::ParseXS)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(Getopt::Long) >= 2.36
BuildRequires:	perl(JSON::PP) >= 2
BuildRequires:	perl(Pod::Man)
BuildRequires:	perl(TAP::Harness::Env)
# Test
BuildRequires:	perl(blib)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(File::ShareDir)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IPC::Open2)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(XSLoader)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(CPAN::Requirements::Dynamic)
Requires:	perl(DynaLoader)
Requires:	perl(ExtUtils::CBuilder)
Requires:	perl(ExtUtils::ParseXS)
Requires:	perl(Pod::Man)
Requires:	perl(TAP::Harness::Env)

%description
Many Perl distributions use a Build.PL file instead of a Makefile.PL file to
drive distribution configuration, build, test and installation. Traditionally,
Build.PL uses Module::Build as the underlying build system. This module
provides a simple, lightweight, drop-in replacement.

Whereas Module::Build has over 6,700 lines of code; this module has less than
70, yet supports the features needed by most pure-Perl distributions.

%prep
%setup -q -n Module-Build-Tiny-%{version}

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
AUTHOR_TESTING=1 RELEASE_TESTING=1 ./Build test

%files
%license LICENSE
%doc Changes README Todo
%{perl_vendorlib}/Module/
%{_mandir}/man3/Module::Build::Tiny.3*

%changelog
* Mon Apr 29 2024 Paul Howarth <paul@city-fan.org> - 0.048-1
- Update to 0.048
  - Implement dynamic prerequisites

* Fri Sep 29 2023 Paul Howarth <paul@city-fan.org> - 0.047-1
- Update to 0.047
  - Avoid using empty regex for backwards compatability

* Fri Jun  2 2023 Paul Howarth <paul@city-fan.org> - 0.046-1
- Update to 0.046
  - Add src/ to include paths

* Mon May  1 2023 Paul Howarth <paul@city-fan.org> - 0.045-1
- Update to 0.045
  - Fix compilation issue on Windows

* Fri Apr 28 2023 Paul Howarth <paul@city-fan.org> - 0.044-1
- Update to 0.044
  - Add module sharedirs
  - Only add src/*.c files to primary XS file

* Wed Apr 19 2023 Paul Howarth <paul@city-fan.org> - 0.043-1
- Update to 0.043
  - Restore manpage generation
  - Add include/ to include paths
  - Compile all .c files in src/

* Tue Apr 18 2023 Paul Howarth <paul@city-fan.org> - 0.041-1
- Update to 0.041
  - Manify .pod after .pm
  - Filter out script documentation from scripts
  - Don't manify podless modules/scripts
- Use SPDX-format license tag
- Standardize permissions of packaged files
- Use %%license unconditionally
- Update URL to https://github.com/Perl-Toolchain-Gang/module-build-tiny
- Add fix for POD generation (GH#29)

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 0.039-13
- Perl 5.30 rebuild

* Thu Apr 26 2018 Paul Howarth <paul@city-fan.org> - 0.039-9
- Drop explicit perl-devel test dependency as ExtUtils::CBuilder pulls it in
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Tue Sep  6 2016 Paul Howarth <paul@city-fan.org> - 0.039-5
- BR: perl-generators where available
- BR: perl-devel for tests

* Mon Oct 13 2014 Paul Howarth <paul@city-fan.org> - 0.039-1
- Update to 0.039
  - Supply basename to *.PL files as its args

* Mon Sep 22 2014 Paul Howarth <paul@city-fan.org> - 0.038-1
- Update to 0.038
  - Scrub PERL_MB_OPT in tests too

* Fri Sep 12 2014 Paul Howarth <paul@city-fan.org> - 0.037-2
- Perl 5.20 rebuild

* Mon Jul 28 2014 Paul Howarth <paul@city-fan.org> - 0.037-1
- Update to 0.037
  - Scrub environment variable in tests
- Use %%license where possible

* Fri May  2 2014 Paul Howarth <paul@city-fan.org> - 0.036-1
- Update to 0.036
  - Add --jobs argument to MBT
  - Add xs directory to include list

* Tue Feb 18 2014 Paul Howarth <paul@city-fan.org> - 0.035-1
- Update to 0.035
  - Fix install test in absence of a compiler

* Wed Jan 22 2014 Paul Howarth <paul@city-fan.org> - 0.034-1
- Update to 0.034
  - Make install tests more platform independent
- Drop %%defattr, redundant since rpm 4.4

* Tue Jan 21 2014 Paul Howarth <paul@city-fan.org> - 0.033-1
- Update to 0.033
  - Require Getopt::Long 2.36
  - Add install tests
- Update patch for building with old Test::More versions

* Mon Jan 20 2014 Paul Howarth <paul@city-fan.org> - 0.032-1
- Update to 0.032
  - Process argument sources separately
  - Use mod2fname appropriately
- BR:/R: perl(DynaLoader)
- BR: perl(GetOpt::Long) ≥ 2.36 for GetOptionsFromArray
- Drop dependencies on TAP::Harness as we only use TAP::Harness::Env

* Fri Oct 11 2013 Paul Howarth <paul@city-fan.org> - 0.030-1
- Update to 0.030
  - 'include_dirs' must be a list ref, not just a string (CPAN RT#54606)

* Fri Oct 11 2013 Paul Howarth <paul@city-fan.org> - 0.029-1
- Update to 0.029
  - Respect harness environmental variables
  - Add main dir to include path
- BR:/R: perl(TAP::Harness) ≥ 3.29

* Mon Sep 30 2013 Paul Howarth <paul@city-fan.org> - 0.028-1
- Update to 0.028
  - Revert "Removed clean and realclean actions"
  - Build .c and .o in temp/ instead of lib
  - Got rid of IO layers
  - Separate libdoc and bindoc checks

* Mon Sep  9 2013 Paul Howarth <paul@city-fan.org> - 0.027-1
- Update to 0.027
  - Various documentation updates

* Tue Aug 20 2013 Paul Howarth <paul@city-fan.org> - 0.026-1
- Update to 0.026
  - Safe PERL_MB_OPT during configuration stage

* Sun Jul 21 2013 Paul Howarth <paul@city-fan.org> - 0.025-2
- Perl 5.18 rebuild

* Fri Jul 12 2013 Paul Howarth <paul@city-fan.org> - 0.025-1
- Update to 0.025
  - Use local tempdir

* Mon Jul  1 2013 Paul Howarth <paul@city-fan.org> - 0.024-2
- BR: perl(File::ShareDir) for the test suite

* Sun Jun 30 2013 Paul Howarth <paul@city-fan.org> - 0.024-1
- Update to 0.024
  - Generate man pages in the correct section

* Wed Jun 12 2013 Paul Howarth <paul@city-fan.org> - 0.023-1
- Update to 0.023
  - Implement --pureperl-only
  - Skip compilation test when not having a compiler
- Update patch for building with old Test::More versions

* Sat Jun  1 2013 Paul Howarth <paul@city-fan.org> - 0.022-1
- Update to 0.022
  - Fix dirname code for toplevel XS modules

* Mon May 27 2013 Paul Howarth <paul@city-fan.org> - 0.021-1
- Update to 0.021
  - Add XS support
  - Only manify if really installable
- BR:/R: perl(ExtUtils::CBuilder) and perl(ExtUtils::ParseXS)
- BR: perl(XSLoader) for the test suite
- Update patch for building with old Test::More versions

* Mon May 20 2013 Paul Howarth <paul@city-fan.org> - 0.020-1
- Update to 0.020
  - Accept a --create_packlist argument

* Tue Apr 30 2013 Paul Howarth <paul@city-fan.org> - 0.019-1
- Update to 0.019
  - Accept --pureperl-only
- Bump perl(ExtUtils::Helpers) version requirement to 0.020

* Thu Apr 25 2013 Paul Howarth <paul@city-fan.org> - 0.018-1
- Update to 0.018
  - Lazily load Pod::Man and TAP::Harness
  - Don't manify unless necessary
- Bump perl(ExtUtils::Helpers) version requirement to 0.019
- Explicitly require perl(Pod::Man) and perl(TAP::Harness) ≥ 3.0

* Tue Apr 23 2013 Paul Howarth <paul@city-fan.org> - 0.017-3
- Updates following package review (#947455)
  - BR: perl(ExtUtils::Config) for module
  - Drop BR: perl(File::Basename) and perl(File::Find), not dual-lived

* Mon Apr 15 2013 Paul Howarth <paul@city-fan.org> - 0.017-2
- Bump perl(ExtUtils::Helpers) version requirement to 0.017 to avoid the need
  for a workaround for misplaced manpage

* Sat Apr 13 2013 Paul Howarth <paul@city-fan.org> - 0.017-1
- Update to 0.017
  - Switched back from JSON to JSON::PP
  - Remove dependency on File::Find::Rule
  - Switched back to ExtUtils::Helpers for detildefy
  - Drop .modulebuildrc support per Lancaster consensus
  - Fix loading of File::Find
  - Fix redefined warning for find
- Update patch for building with old Test::More versions
- Drop BR: perl(ExtUtils::BuildRC), perl(File::Find::Rule), perl(File::HomeDir),
  perl(File::pushd)
- BR: perl(JSON::PP) rather than perl(JSON), and perl(Pod::Man)
- Bump perl(ExtUtils::Helpers) version requirement to 0.016
- Add workaround for misplaced manpage
  (https://github.com/Leont/module-build-tiny/issues/2)

* Thu Apr  4 2013 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Added sharedir support
  - Fixed Synopsis
  - Make blib/arch, to satisfy blib.pm
  - Removed dependencies on Test::Exception, Capture::Tiny and File::Slurp
- Update patch for building with old Test::More versions

* Mon Apr  1 2013 Paul Howarth <paul@city-fan.org> - 0.013-1
- Initial RPM version
